@@ -3,6 +3,7 @@ from django.utils import simplejson as json
 
 from lizard_map.daterange import current_start_end_dates
 from lizard_map.models import Workspace
+from lizard_map.utility import float_to_string
 from lizard_map.views import CUSTOM_LEGENDS
 
 register = template.Library()
@@ -95,15 +96,7 @@ def json_escaped(value):
 @register.filter
 def float_or_exp(value):
     """Show number with 2 decimals or with an exponent if too small."""
-    try:
-        float(value)
-    except (TypeError, ValueError):
-        # It is not a number so we just pass it on.
-        return value
-    if 0 < abs(value) < 0.01:
-        return '%.2e' % value
-    return '%.2f' % value
-
+    return float_to_string(value)
 
 @register.inclusion_tag("lizard_map/tag_date_popup.html",
                         takes_context=True)
